===========
Django Suit
===========

**Modern theme for Django admin interface**.

Django Suit is alternative theme/skin/extension for `Django <http://www.djangoproject.com>`_ administration interface.

v2 version is working with Django 3.2 and Django 4.0, it is using Bootstrap 5.1

* Project home: http://djangosuit.com/ (not maintained)


License
=======
 (not maintained)
* Django Suit is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.
* Licence and pricing: http://djangosuit.com/pricing/


Docs & Support
==============

* Documentation v2: http://django-suit.readthedocs.org/en/v2/ (not maintained)
* Support: http://djangosuit.com/support/ (not maintained)

Changelog
=========

**Note:** Django Suit v2.0 is in active development and not yet ready for production use.

Read more here: Todo: Add issue reference

Install
=========
Install Django Suit v2 using ``pip`` or ``easy_install``::

    pip install django-suit-v2-pm


Contributing
============

See `Contributing documentation <http://django-suit.readthedocs.org/en/v2/contribute.html>`_


Build Status
============

Tested using Python: 3.8 and PyPy + Django: 3.2 (LTS), Django 4.0, Django 4.1, Django 4.2 (LTS)